[Bf-blender-cvs] [209686f1c81] hair_guides_grooming: Merge branch 'hair_guides' into hair_guides_grooming

Lukas Tönne noreply at git.blender.org
Sun Aug 12 12:17:55 CEST 2018


Commit: 209686f1c8189bc01f91d14a922651844df8b201
Author: Lukas Tönne
Date:   Sun Aug 12 11:17:33 2018 +0100
Branches: hair_guides_grooming
https://developer.blender.org/rB209686f1c8189bc01f91d14a922651844df8b201

Merge branch 'hair_guides' into hair_guides_grooming

===================================================================



===================================================================

diff --cc source/blender/draw/intern/draw_cache.h
index 8678f9b1f5c,aef32291215..2702303e06a
--- a/source/blender/draw/intern/draw_cache.h
+++ b/source/blender/draw/intern/draw_cache.h
@@@ -31,10 -31,8 +31,9 @@@ struct GPUMaterial
  struct ModifierData;
  struct Object;
  struct PTCacheEdit;
 +struct Groom;
  struct HairSystem;
  struct HairExportCache;
- struct DRWHairFiberTextureBuffer;
  
  void DRW_shape_cache_free(void);
  void DRW_shape_cache_reset(void);
diff --cc source/blender/draw/intern/draw_cache_impl.h
index d6c117321a7,caef4979ee3..9cd114c1454
--- a/source/blender/draw/intern/draw_cache_impl.h
+++ b/source/blender/draw/intern/draw_cache_impl.h
@@@ -36,10 -36,8 +36,9 @@@ struct ListBase
  struct ModifierData;
  struct ParticleSystem;
  struct PTCacheEdit;
 +struct Groom;
  struct HairSystem;
  struct HairExportCache;
- struct DRWHairFiberTextureBuffer;
  
  struct Curve;
  struct Lattice;



More information about the Bf-blender-cvs mailing list
diff --cc source/blender/blenkernel/BKE_hair.h
index adea3696893,e24effd9227..3f35e151ada
--- a/source/blender/blenkernel/BKE_hair.h
+++ b/source/blender/blenkernel/BKE_hair.h
@@@ -53,32 -53,26 +53,32 @@@ struct HairSystem* BKE_hair_copy(struc
  /* Delete a hair system */
  void BKE_hair_free(struct HairSystem *hsys);
  
- /* === Guide Strands === */
+ /* === Fiber curves === */
  
  /* Allocate buffers for defining guide curves
   * \param totcurves Number of guide curves to allocate
 + * \param totverts Number of guide curve vertices to allocate
 + */
 +void BKE_hair_guide_curves_alloc(struct HairSystem *hsys, int totcurves, int totverts);
 +
 +/* Allocate buffers for defining guide curves
 + * \param totcurves Number of guide curves to allocate
   */
- void BKE_hair_guide_curves_begin(struct HairSystem *hsys, int totcurves);
+ void BKE_hair_fiber_curves_begin(struct HairSystem *hsys, int totcurves);
  
  /* Set properties of a guide curve
   * \param index Index of the guide guide curve
   * \param mesh_sample Origin of the guide curve on the scalp mesh.
   * \param numverts Number of vertices in this guide curve
   */
- void BKE_hair_set_guide_curve(struct HairSystem *hsys, int index, const struct MeshSample *mesh_sample, int numverts,
+ void BKE_hair_set_fiber_curve(struct HairSystem *hsys, int index, int numverts,
                                float taper_length, float taper_thickness);
  
- /* Finalize guide curve update */
- void BKE_hair_guide_curves_end(struct HairSystem *hsys);
+ /* Finalize fiber curve update */
+ void BKE_hair_fiber_curves_end(struct HairSystem *hsys);
  
  /* Set properties of a guide curve vertex
   * \param index Index of the guide curve vertex.
   * \param flag Flags to set on the vertex.
   * \param co Location of the vertex in object space.
   */
@@@ -53,32 -53,26 +53,32 @@@ struct HairSystem* BKE_hair_copy(struc
  
- /* Allocate buffers for defining guide curves
-  * \param totcurves Number of guide curves to allocate
+ /* Allocate buffers for defining fiber curves
+  * \param totcurves Number of fiber curves to allocate
 + * \param totverts Number of guide curve vertices to allocate
 + */
@@@ -53,32 -53,26 +53,32 @@@ struct HairSystem* BKE_hair_copy(struc
  
- /* Set properties of a guide curve
-  * \param index Index of the guide guide curve
-  * \param mesh_sample Origin of the guide curve on the scalp mesh.
-  * \param numverts Number of vertices in this guide curve
+ /* Set properties of a fiber curve
+  * \param index Index of the fiber curve
+  * \param mesh_sample Origin of the fiber curve on the scalp mesh.
+  * \param numverts Number of vertices in this fiber curve
   */
@@@ -53,32 -53,26 +53,32 @@@ struct HairSystem* BKE_hair_copy(struc
  
- /* Set properties of a guide curve vertex
-  * \param index Index of the guide curve vertex.
+ /* Set properties of a fiber curve vertex
+  * \param index Index of the fiber curve vertex.
   * \param flag Flags to set on the vertex.
   * \param co Location of the vertex in object space.